#
# spec file for package kscreenlocker6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global kf6_version 6.0.0
%define qt6_version 6.7.0

%define rname kscreenlocker
%bcond_without released
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Name:           kscreenlocker6
Version:        6.3.4
Release:        1.1.2.1.sr20250402
Summary:        Library and components for secure lock screen architecture
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
Source3:        kde
Source4:        kde-fingerprint
Source5:        kde-smartcard
BuildRequires:  cmake >= 3.16
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IdleTime) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Screen) >= %{_plasma6_bugfix}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6Svg) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(KWayland) >= %{_plasma6_bugfix}
BuildRequires:  cmake(LayerShellQt) >= %{_plasma6_bugfix}
BuildRequires:  cmake(PlasmaQuick) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-xtest)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
Requires:       pam-config
Provides:       kscreenlocker = %{version}
Provides:       qt6qmlimport(org.kde.kscreenlocker.1) = 0
Obsoletes:      kscreenlocker < %{version}
Obsoletes:      kscreenlocker-lang < %{version}

%description
Library and components for secure lock screen architecture.

%package -n libKScreenLocker6
Summary:        Library and components for secure lock screen architecture

%description -n libKScreenLocker6
Library and components for secure lock screen architecture.

%package devel
Summary:        Library and components for secure lock screen architecture - development files
Requires:       libKScreenLocker6 = %{version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Conflicts:      kscreenlocker-devel

%description devel
Development files for Library and components for secure lock screen architecture.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

# Ship our own files to not depend on a display manager being installed (boo#1108329)
install -D -m0644 %{SOURCE3} %{buildroot}%{_pam_vendordir}/kde
install -D -m0644 %{SOURCE4} %{buildroot}%{_pam_vendordir}/kde-fingerprint
install -D -m0644 %{SOURCE5} %{buildroot}%{_pam_vendordir}/kde-smartcard

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKScreenLocker6

%files
%license LICENSES/*
%{_kf6_applicationsdir}/kcm_screenlocker.desktop
%{_kf6_debugdir}/kscreenlocker.categories
%{_kf6_notificationsdir}/ksmserver.notifyrc
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_screenlocker.so
%{_kf6_sharedir}/ksmserver/
%{_libexecdir}/kscreenlocker_greet
%{_pam_vendordir}/kde
%{_pam_vendordir}/kde-fingerprint
%{_pam_vendordir}/kde-smartcard

%files -n libKScreenLocker6
%{_kf6_libdir}/libKScreenLocker.so.*

%files devel
%{_includedir}/KScreenLocker/
%{_kf6_cmakedir}/KScreenLocker/
%{_kf6_cmakedir}/ScreenSaverDBusInterface/
%{_kf6_libdir}/libKScreenLocker.so
%{_kf6_sharedir}/dbus-1/interfaces/kf6_org.freedesktop.ScreenSaver.xml
%{_kf6_sharedir}/dbus-1/interfaces/org.kde.screensaver.xml

%files lang -f %{name}.lang

%changelog
* Wed Apr  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.3.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/6/6.3.4
- Changes since 6.3.3:
  * update version for new release
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * update version for new release
  * Explictly register DBus metatypes for shortcuts
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
  * Remove and add idle timeout when inhibited and unhibited (kde#469687)
  * X11Locker: always call stayOnTop when receiving XCB_MAP_NOTIFY to fix black screen
  * Update .gitignore to ignore build folder
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
  * globalaccel: whitelist Toggle Keyboard Backlight (kde#483919)
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Changes since 6.2.5:
  * update version for new release
  * greeter: Don't turn off screen using DPMS in testing mode
  * greeter: Conditionalise autotests here too
  * Cleanup unused HAVE_SIGNALFD_H, HAVE_EVENT_H from config-kscreenlocker.h.cmake
  * cmake: Drop now unused UnixAuth.cmake
  * Drop obsolete ConfigureChecks.cmake
  * README.pam: Mention PAM is required and cleanup obsolete bits
  * Drop unused PAM_REQUIRED cmake option, unconditionally find PAM (kde#455303)
  * Make it compile without deprecated methods
  * x11locker: lower m_background when hiding
  * Don't include quiet packages in feature_summary
  * update version for new release
  * ksldapp: don't wait for the screen locker process to exit in the grace lock case
  * Add missing Q_EMIT
  * greeter: Fix signal invocation on QNetworkReply
  * pamtest: Use QStringLiteral
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
  * x11locker: lower m_background when hiding
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * greeter: Fix signal invocation on QNetworkReply
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * set and check for the DEP version for dependencies so as not to upset CI in common with other Plasma packages
  * update version for new release
  * Move to a newer KDE_COMPILERSETTINGS_LEVEL
  * KSldTest: Change all durations to std:chrono
  * KSldTest: Warn the user that unintended inputs may interrupt the test
  * autotests: Don't try to run X11-specific code under Wayland
  * greeter/pamauthenticators: also consider non-interactive info messages a "prompt" (kde#490547)
  * greeter/authenticators: add a property for if a prompt was shown in the past
  * greeter: Change --theme option to --shell option, and make it work
  * kcm: Only use a single Loader for both possible dialogs
  * kcm: Factor out ComboBoxWithCustomValue for later reuse
  * ksldapp: add a signal for when the greeter is (re)started
  * greeter: don't start authenticating during the grace lock time (kde#476567)
  * greeter: Fix Shader Wallpaper plugin and possibly others
  * kcm: Fix some appearance page glitches
  * Port begin/end loops to range iterators
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
  * greeter/pamauthenticators: also consider non-interactive info messages a "prompt" (kde#490547)
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * greeter/authenticators: add a property for if a prompt was shown in the past
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * greeter: Fix Shader Wallpaper plugin and possibly others
  * ksldapp: add a signal for when the greeter is (re)started
  * greeter: don't start authenticating during the grace lock time (kde#476567)
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
  * Handle wl_display_create() failing
  * CI: Add missing dependencies
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * Prevent finishing greeter by unhandled signals
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * update version for new release
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Tue Mar  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Remove kscreenlocker_greet restart in %%post, no longer necessary
  after kcheckpass got removed
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
* Fri Feb 16 2024 Christophe Marin <christophe@krop.fr>
- Remove session mechanism from kscreenlocker pam files (boo#1217189)
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * greeter: Fix pressing Esc to turn off the display (kde#476533)
  * Respect max value of LockGrace in the UI as well
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Wed Nov 15 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add QML module provides
* Sat Jul  1 2023 Christophe Marin <christophe@krop.fr>
- Init kscreenlocker6
